@@ -1,8 +1,8 @@
-#
-# DENOISE.R
-#
+###
+### DENOISE.R
+###
 
-# Enumerated Values
+## Enumerated Values
 DWT.TRANSFORM.TYPE <- as.integer(0)
 UDWT.TRANSFORM.TYPE <- as.integer(1)
 
@@ -12,11 +12,11 @@ STD.VARIANCE.ESTIMATOR <- as.integer(1)    # classical numerical std estimate
 SOFT.THRESHOLD.TYPE <- as.integer(0)
 HARD.THRESHOLD.TYPE <- as.integer(1)
 
-# Sentinel Values
+## Sentinel Values
 MAX.DECOMPOSITION <- 0
 CALC.THRESHOLD.TO.USE <- 0
 
-# Constants
+## Constants
 DEFAULT.DWT.THRESHOLD.MULTIPLIER <- 3.0
 DEFAULT.UDWT.THRESHOLD.MULTIPLIER <- 3.6
 
@@ -36,12 +36,14 @@ default.udwt.option <-
          num.decompression.levels = MAX.DECOMPOSITION,
          threshold                = CALC.THRESHOLD.TO.USE)
 
-#
-# Public
-#
+
+##
+## Public
+##
+
 ##------------------------------------------------------------------------------
 denoise <- function(x, h, type, option) {
-    cat("start denoising via wavelet transform", "\n")
+    message("start denoising via wavelet transform")
     .validate.denoise.args(x, h, type, option)
 
     res <- if (type == DWT.TRANSFORM.TYPE) {
@@ -53,30 +55,31 @@ denoise <- function(x, h, type, option) {
     option <- c(option, type = type)
     option$threshold <- res$thld
 
-    cat("end denoising via wavelet transform", "\n")
-    return(list(xd     = res$xd,
-                xn     = x - res$xd,
-                option = option))
+    message("end denoising via wavelet transform")
+    list(xd     = res$xd,
+         xn     = x - res$xd,
+         option = option)
 }
 
 
 ##------------------------------------------------------------------------------
 denoise.dwt <- function(x, h, option = default.dwt.option) {
-    cat("start decimated wavelet transform", "\n")
-    return(denoise(x, h, DWT.TRANSFORM.TYPE, option))
+    message("start decimated wavelet transform")
+    denoise(x, h, DWT.TRANSFORM.TYPE, option)
 }
 
 
 ##------------------------------------------------------------------------------
 denoise.udwt <- function(x, h, option = default.udwt.option) {
-    cat("start undecimated wavelet transform", "\n")
-    return(denoise(x, h, UDWT.TRANSFORM.TYPE, option))
+    message("start undecimated wavelet transform")
+    denoise(x, h, UDWT.TRANSFORM.TYPE, option)
 }
 
 
-#
-# Private
-#
+##
+## Private
+##
+
 ##------------------------------------------------------------------------------
 .dwt <- function(x, h, option) {
     initValues <- .init.denoise(x, option$num.decompression.levels)
@@ -93,9 +96,9 @@ denoise.udwt <- function(x, h, option = default.udwt.option) {
     if (option$threshold == CALC.THRESHOLD.TO.USE) {
         tmp <- xd[(floor(mx/2)+1):mx, (floor(nx/2)+1):nx]
         if (option$variance.estimator == MAD.VARIANCE.ESTIMATOR) {
-            thld = option$threshold.multiplier * median(abs(tmp)) / 0.67
+            thld <- option$threshold.multiplier * median(abs(tmp)) / 0.67
         } else if (option$variance.estimator == STD.VARIANCE.ESTIMATOR) {
-            thld = option$threshold.multiplier * std(tmp)
+            thld <- option$threshold.multiplier * std(tmp)
         } else {
             stop("unknown variance estimator - use either MAD or STD")
         }
@@ -123,16 +126,16 @@ denoise.udwt <- function(x, h, option = default.udwt.option) {
 
     if (option$threshold.low.pass.part == FALSE) {
         if (dimen == 1) {
-            xd[ix] = ykeep
+            xd[ix] <- ykeep
         } else {
-            xd[ix, jx] = ykeep
+            xd[ix, jx] <- ykeep
         }
     }
 
     ret.midwt <- midwt(xd, h, L)
 
-    return(list(xd   = ret.midwt$x,
-                thld = thld))
+    list(xd   = ret.midwt$x,
+         thld = thld)
 }
 
 
@@ -159,9 +162,9 @@ denoise.udwt <- function(x, h, option = default.udwt.option) {
     if (option$threshold == CALC.THRESHOLD.TO.USE) {
         tmp <- xh[,c.offset:(c.offset+nx-1)]
         if (option$variance.estimator == MAD.VARIANCE.ESTIMATOR) {
-            thld = option$threshold.multiplier * median(abs(tmp)) / 0.67
+            thld <- option$threshold.multiplier * median(abs(tmp)) / 0.67
         } else if (option$variance.estimator == STD.VARIANCE.ESTIMATOR) {
-            thld = option$threshold.multiplier * std(tmp)
+            thld <- option$threshold.multiplier * std(tmp)
         } else {
             stop("unknown variance estimator - use either MAD or STD")
         }
@@ -186,8 +189,8 @@ denoise.udwt <- function(x, h, option = default.udwt.option) {
 
     ret.mirdwt <- mirdwt(xl, xh, h, L)
 
-    return(list(xd   = ret.mirdwt$x,
-                thld = thld))
+    list(xd   = ret.mirdwt$x,
+         thld = thld)
 }
 
 
@@ -208,36 +211,37 @@ denoise.udwt <- function(x, h, option = default.udwt.option) {
              num.levels
          }
 
-    return(list(mx    = mx,
-                nx    = nx,
-                dimen = dimen,
-                n     = n,
-                L     = L))
+    list(mx    = mx,
+         nx    = nx,
+         dimen = dimen,
+         n     = n,
+         L     = L)
 }
 
 
 ##------------------------------------------------------------------------------
 .validate.denoise.args <- function(x, h, type, option) {
     if (!(is.vector(x) || is.matrix(x))) {
-        stop(paste("argument", sQuote("x"), "must be vector or matrix"))
+        stop(sprintf("argument %s must be vector or matrix",
+                     sQuote("x")))
     }
 
     if (!(is.vector(h) &&
           length(h) > 2)) {
-        stop(paste("argument", sQuote("h"),
-                   "must be vector containing an even number of items"))
+        stop(sprintf("argument %s must be vector containing an even number of items",
+                     sQuote("h")))
     }
 
     if (!(type == DWT.TRANSFORM.TYPE ||
           type == UDWT.TRANSFORM.TYPE)) {
-        stop(paste("argument", sQuote("type"),
-                   "specifies unknown transformation"))
+        stop(sprintf("argument %s specifies unknown transformation",
+                     sQuote("type")))
     }
 
     if (!(is.list(option) &&
           length(option) == 6)) {
-        stop(paste("argument", sQuote("option"),
-                   "must be list containing six parameters"))
+        stop(sprintf("argument %s must be list containing six parameters",
+                     sQuote("option")))
     }
 
     .validate.denoise.option.args(option)
@@ -247,30 +251,35 @@ denoise.udwt <- function(x, h, option = default.udwt.option) {
 ##------------------------------------------------------------------------------
 .validate.denoise.option.args <- function(option) {
     if (!(is.logical(option$threshold.low.pass.part))) {
-        stop(paste("argument", sQuote("option[[1]]"), "must be logical"))
+        stop(sprintf("argument %s must be logical",
+                     sQuote("option[[1]]")))
     }
 
     if (!(is.numeric(option$threshold.multiplier))) {
-        stop(paste("argument", sQuote("option[[2]]"), "must be numeric"))
+        stop(sprintf("argument %s must be numeric",
+                     sQuote("option[[2]]")))
     }
 
     if (!(option$variance.estimator == MAD.VARIANCE.ESTIMATOR ||
           option$variance.estimator == STD.VARIANCE.ESTIMATOR)) {
-        stop(paste("argument", sQuote("option[[3]]"), "must be 0 or 1"))
+        stop(sprintf("argument %s must be 0 or 1",
+                     sQuote("option[[3]]")))
     }
 
     if (!(option$threshold.type == SOFT.THRESHOLD.TYPE ||
           option$threshold.type == HARD.THRESHOLD.TYPE)) {
-        stop(paste("argument", sQuote("option[[4]]"), "must be 0 or 1"))
+        stop(sprintf("argument %s must be 0 or 1",
+                     sQuote("option[[4]]")))
     }
 
     if (!(as.integer(option$num.decompression.levels) >= 0)) {
-        stop(paste("argument", sQuote("option[[5]]"), "must be natural number"))
+        stop(sprintf("argument %s must be natural number",
+                     sQuote("option[[5]]")))
     }
 
     if (!(is.numeric(option$threshold))) {
-        stop(paste("argument", sQuote("option[[6]]"),
-                   "must be numeric vector or 0"))
+        stop(sprintf("argument %s must be numeric vector or 0",
+                     sQuote("option[[6]]")))
     }
 }
 
