@@ -1,6 +1,6 @@
-#
-# HARDTH.R
-#
+###
+### HARDTH.R
+###
 
 #%    x = HardTh(y,thld); 
 #%
@@ -28,13 +28,12 @@
 #%       x = 1.5545 5.3175 0 1.6956  -1.2678 0 1.7332 0
 #%
 
-#
-# Public
-#
+##
+## Public
+##
+
 ##-----------------------------------------------------------------------------
 hardTh <- function(y, thld) {
-    x = (abs(y) > thld) * y
-
-    return(x)
+    (abs(y) > thld) * y
 }
 
